{ pkgs ? import <nixpkgs> {} }:
pkgs.stdenv.mkDerivation rec {
  pname = "fairfax-hd";
  version = "2024-06-01";

  src = pkgs.fetchzip {
    url = "https://github.com/kreativekorp/open-relay/releases/download" +
          "/2024-06-01/FairfaxHD.zip";
    hash = "sha256-kwdpWFOYhXt0HNqfWP3EeKYhJWgKsRs7cAbzHEasM80=";
    stripRoot = false;
  };

  installPhase = ''
    dir=$out/share/fonts/opentype
    mkdir -p $dir
    cp ${src}/*.ttf $dir
  '';

  outputHashMode = "recursive";
  outputHash = "sha256-oNWvAFZ1ntjtSEreI4daf/i7yhRhGnHFPTyHj1g2l3I=";

  meta = {
    homepage = "https://www.kreativekorp.com/software/fonts/fairfaxhd";
    description = "monospace font with support for many conlangs";
    longDescription = ''
      Fairfax HD is a halfwidth scalable monospace font for terminals, text
      editors, IDEs, etc. It supports many scripts and a large number of Unicode
      blocks as well as constructed scripts as encoded in the
      [Under-ConScript Unicode Registry][ucsur], pseudographics and
      semigraphics, and tons of private use characters.

      [ucsur]: https://www.kreativekorp.com/ucsur
    '';
    platforms = pkgs.lib.platforms.all;
  };
}
